==> jc-1.4.0.tar.gz: javax/swing/PopupFactory.h <==
// public class javax.swing.PopupFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 578a9d6d8fb59987 javax_swing_PopupFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_PopupFactory_H_
#define _JC_javax_swing_PopupFactory_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Popup$object;
struct _jc_javax_swing_PopupFactory$object;

// Typedefs
typedef struct _jc_javax_swing_PopupFactory$sub_refs	_jc_javax_swing_PopupFactory$sub_refs;
typedef struct _jc_javax_swing_PopupFactory$sub_nonrefs	_jc_javax_swing_PopupFactory$sub_nonrefs;
typedef struct _jc_javax_swing_PopupFactory$refs	_jc_javax_swing_PopupFactory$refs;
typedef struct _jc_javax_swing_PopupFactory$nonrefs	_jc_javax_swing_PopupFactory$nonrefs;
typedef struct _jc_javax_swing_PopupFactory$object	_jc_javax_swing_PopupFactory$object;

typedef struct _jc_javax_swing_PopupFactory$fields_struct	_jc_javax_swing_PopupFactory$fields_struct;
typedef const struct _jc_javax_swing_PopupFactory$vmethods	_jc_javax_swing_PopupFactory$vmethods;
typedef const struct _jc_javax_swing_PopupFactory$vtable	_jc_javax_swing_PopupFactory$vtable;
typedef const struct _jc_javax_swing_PopupFactory$vtype	_jc_javax_swing_PopupFactory$vtype;

// Class fields structure
struct _jc_javax_swing_PopupFactory$fields_struct {
	struct _jc_javax_swing_PopupFactory$object	*sharedFactory;
};
extern _jc_javax_swing_PopupFactory$fields_struct _jc_javax_swing_PopupFactory$class_fields;

// Constructors
extern void _jc_javax_swing_PopupFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_PopupFactory$object *);

// Virtual methods
extern struct _jc_javax_swing_Popup$object *_jc_javax_swing_PopupFactory$method$getPopup$790ff9eb1b12882c(_jc_env *, struct _jc_javax_swing_PopupFactory$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Component$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_PopupFactory$method_info$getPopup$790ff9eb1b12882c;

// Static methods
extern struct _jc_javax_swing_PopupFactory$object *_jc_javax_swing_PopupFactory$method$getSharedInstance$94ec94866535d9e0(_jc_env *);
extern void _jc_javax_swing_PopupFactory$method$setSharedInstance$6c5c788079d771cf(_jc_env *, struct _jc_javax_swing_PopupFactory$object *);

// Virtual methods structure
struct _jc_javax_swing_PopupFactory$vmethods {
	struct _jc_javax_swing_Popup$object	*(*getPopup$790ff9eb1b12882c)(_jc_env *, struct _jc_javax_swing_PopupFactory$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Component$object *, jint, jint);
};

// Vtable
struct _jc_javax_swing_PopupFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_PopupFactory$vmethods	javax_swing_PopupFactory;
};

// Vtype
struct _jc_javax_swing_PopupFactory$vtype {
	_jc_type			type;
	_jc_javax_swing_PopupFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_PopupFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_PopupFactory$refs {
    _jc_javax_swing_PopupFactory$sub_refs	javax_swing_PopupFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_PopupFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_PopupFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_PopupFactory$sub_nonrefs	javax_swing_PopupFactory;
};

// Object instance structure
struct _jc_javax_swing_PopupFactory$object {
	_jc_javax_swing_PopupFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_PopupFactory$vtype	*vtype;
	_jc_javax_swing_PopupFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_PopupFactory$vtype _jc_javax_swing_PopupFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_PopupFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_PopupFactory$class_object;

#endif	/* _JC_javax_swing_PopupFactory_H_ */

==> jc-1.4.6.tar.gz: javax/swing/PopupFactory.h <==
// public class javax.swing.PopupFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 578a9d6d8fb59987 javax_swing_PopupFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_PopupFactory_H_
#define _JC_javax_swing_PopupFactory_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Popup$object;
struct _jc_javax_swing_PopupFactory$object;

// Typedefs
typedef struct _jc_javax_swing_PopupFactory$sub_refs	_jc_javax_swing_PopupFactory$sub_refs;
typedef struct _jc_javax_swing_PopupFactory$sub_nonrefs	_jc_javax_swing_PopupFactory$sub_nonrefs;
typedef struct _jc_javax_swing_PopupFactory$refs	_jc_javax_swing_PopupFactory$refs;
typedef struct _jc_javax_swing_PopupFactory$nonrefs	_jc_javax_swing_PopupFactory$nonrefs;
typedef struct _jc_javax_swing_PopupFactory$object	_jc_javax_swing_PopupFactory$object;

typedef struct _jc_javax_swing_PopupFactory$fields_struct	_jc_javax_swing_PopupFactory$fields_struct;
typedef const struct _jc_javax_swing_PopupFactory$vmethods	_jc_javax_swing_PopupFactory$vmethods;
typedef const struct _jc_javax_swing_PopupFactory$vtable	_jc_javax_swing_PopupFactory$vtable;
typedef const struct _jc_javax_swing_PopupFactory$vtype	_jc_javax_swing_PopupFactory$vtype;

// Class fields structure
struct _jc_javax_swing_PopupFactory$fields_struct {
	struct _jc_javax_swing_PopupFactory$object	*sharedFactory;
};
extern _jc_javax_swing_PopupFactory$fields_struct _jc_javax_swing_PopupFactory$class_fields;

// Constructors
extern void _jc_javax_swing_PopupFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_PopupFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_Popup$object *_jc_javax_swing_PopupFactory$method$getPopup$790ff9eb1b12882c(_jc_env *, struct _jc_javax_swing_PopupFactory$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Component$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_PopupFactory$method_info$getPopup$790ff9eb1b12882c;

// Static methods
extern struct _jc_javax_swing_PopupFactory$object *_jc_javax_swing_PopupFactory$method$getSharedInstance$94ec94866535d9e0(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_PopupFactory$method$setSharedInstance$6c5c788079d771cf(_jc_env *, struct _jc_javax_swing_PopupFactory$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_PopupFactory$vmethods {
	struct _jc_javax_swing_Popup$object	*(*getPopup$790ff9eb1b12882c)(_jc_env *, struct _jc_javax_swing_PopupFactory$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Component$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_PopupFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_PopupFactory$vmethods	javax_swing_PopupFactory;
};

// Vtype
struct _jc_javax_swing_PopupFactory$vtype {
	_jc_type			type;
	_jc_javax_swing_PopupFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_PopupFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_PopupFactory$refs {
    _jc_javax_swing_PopupFactory$sub_refs	javax_swing_PopupFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_PopupFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_PopupFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_PopupFactory$sub_nonrefs	javax_swing_PopupFactory;
};

// Object instance structure
struct _jc_javax_swing_PopupFactory$object {
	_jc_javax_swing_PopupFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_PopupFactory$vtype	*vtype;
	_jc_javax_swing_PopupFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_PopupFactory$vtype _jc_javax_swing_PopupFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_PopupFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_PopupFactory$class_object;

#endif	/* _JC_javax_swing_PopupFactory_H_ */
